/*******************************************************************************
 * Copyright (c) 2007 Symbian Software Limited and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Bala Torati (Symbian) - Initial API and implementation
 *******************************************************************************/
package org.eclipse.cdt.core.templateengine;

/**
 * @noreference This class is not intended to be referenced by clients.
 * @deprecated Provide your own messages.
 */
@Deprecated
public class TemplateEngineMessages {
	private TemplateEngineMessages() {
	}

	public static String ProcessRunner_missingArg;

	public static String getString(String key) {
		throw new UnsupportedOperationException();
	}
}
